import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_dj2iu","start":"checkbox__start_dj2iu","center":"checkbox__center_dj2iu","addons":"checkbox__addons_dj2iu","block":"checkbox__block_dj2iu","box":"checkbox__box_dj2iu","checkedIcon":"checkbox__checkedIcon_dj2iu","s":"checkbox__s_dj2iu","disabled":"checkbox__disabled_dj2iu","checked":"checkbox__checked_dj2iu","indeterminate":"checkbox__indeterminate_dj2iu","label":"checkbox__label_dj2iu","hint":"checkbox__hint_dj2iu","focused":"checkbox__focused_dj2iu","content":"checkbox__content_dj2iu","indeterminateLine":"checkbox__indeterminateLine_dj2iu"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
